@@ -6,13 +6,22 @@
 #
 # For python 3
 
-import socketserver
-import xmlrpc.server
+import sys
 
-class ThreadingXMLRPCServer(socketserver.ThreadingMixIn, xmlrpc.server.SimpleXMLRPCServer):
-    """ThreadingXMLRPCServer
-    """
-    pass
+if sys.version_info.major == 2:
+    import SocketServer
+    import SimpleXMLRPCServer
+
+    class ThreadingXMLRPCServer(SocketServer.ThreadingMixIn, SimpleXMLRPCServer.SimpleXMLRPCServer):
+        pass
+else:
+    import socketserver
+    import xmlrpc.server
+
+    class ThreadingXMLRPCServer(socketserver.ThreadingMixIn, xmlrpc.server.SimpleXMLRPCServer):
+        """ThreadingXMLRPCServer
+        """
+        pass
 
 class IF_server:
     """IF_Server
